Contributing
============

Contributions are welcome! If you have a model you'd like to implement or an
improvement to an existing model, please refer to our detailed
`Contributing Guide <markdown/CONTRIBUTING.md>`_.

By participating in this project, you agree to abide by the
`Code of Conduct <markdown/CODE_OF_CONDUCT.md>`_.

Thank you for your contributions!
